@@ -29,7 +29,7 @@ HD_DEFINE_PLUGIN_MODULE(ConnectNowHomePlugin, connect_now_home_plugin, HD_TYPE_H
 
 
 #define CONNECT_NOW_HOME_PLUGIN_SETTINGS_FILE "/.connectnow_home_widget"
-#define CONNECT_NOW_WIDGET_WIDTH 64
+#define CONNECT_NOW_WIDGET_WIDTH 84
 
 static GtkWidget*
 build_ui()
@@ -155,8 +155,25 @@ read_settings(ConnectNowHomePlugin *desktop_plugin)
   if(fileExists)
   {
     GError *error = NULL;
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, "connectedIcon", NULL))
+      {
+	desktop_plugin->connectedImageName = g_key_file_get_string(keyFile, desktop_plugin->iD, "connectedIcon", NULL);
+	desktop_plugin->connectedImage = gdk_pixbuf_new_from_file_at_scale(desktop_plugin->connectedImageName,
+									   CONNECT_NOW_WIDGET_WIDTH,
+									   CONNECT_NOW_WIDGET_WIDTH,
+									   FALSE,
+									   NULL);
+      }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, "disconnectedIcon", NULL))
+      {
+	desktop_plugin->disconnectedImageName = g_key_file_get_string(keyFile, desktop_plugin->iD, "disconnectedIcon", NULL);
+	desktop_plugin->disconnectedImage = gdk_pixbuf_new_from_file_at_scale(desktop_plugin->disconnectedImageName,
+									   CONNECT_NOW_WIDGET_WIDTH,
+									   CONNECT_NOW_WIDGET_WIDTH,
+									   FALSE,
+									   NULL);
+      }
     desktop_plugin->connection_name = g_key_file_get_string(keyFile, desktop_plugin->iD, "connection_name", &error);
-
     if(!error)
     {
       desktop_plugin->connection_id = g_key_file_get_string(keyFile, desktop_plugin->iD, "connection_id", &error);
@@ -167,7 +184,6 @@ read_settings(ConnectNowHomePlugin *desktop_plugin)
 	g_free(fileName);
 	return;
       }
-	  
     }
     g_error_free(error);
     error = NULL;
@@ -301,6 +317,8 @@ connect_now_home_plugin_init(ConnectNowHomePlugin *desktop_plugin)
   desktop_plugin->connection_name = NULL;
   desktop_plugin->connection_id = NULL;
   desktop_plugin->current_connection_id = NULL;
+  desktop_plugin->connectedImageName = NULL;
+  desktop_plugin->disconnectedImageName = NULL;
 
   desktop_plugin->this_connection_state = CON_IC_STATUS_DISCONNECTED;
   desktop_plugin->connect_now = FALSE;
@@ -342,81 +360,102 @@ connect_now_expose(GtkWidget* widget, GdkEventExpose *event)
   gdk_cairo_region(cr, event->region);
   cairo_clip(cr);
   cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
-  cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.0);
-  cairo_paint(cr);
 
-  cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.4);
-  cairo_rectangle(cr, 0, 0, CONNECT_NOW_WIDGET_WIDTH, CONNECT_NOW_WIDGET_WIDTH);
-  cairo_fill(cr);
-
-  cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
-  cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
-  cairo_arc(cr, 30, 39, 2.0, 0, 2*M_PI);
-  cairo_fill(cr);
-
-  if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_CONNECTED)
+  if(CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage &&
+     CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage)
   {
-    cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
-  }
-  else if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_DISCONNECTED)
-  {
-    cairo_set_source_rgba(cr, 0.6, 0.6, 0.6, 0.7);
-  }
-  else if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_DISCONNECTING)
-  {
-    cairo_set_source_rgba(cr, 0.8, 0.8, 0.8, 1.0);
-  }
-    
-  cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND); 
-
-  cairo_set_line_width(cr, 4.0);
-  double frac = (M_PI/180.0);
-  cairo_arc(cr, 30, 40, 10, 224 * frac, 316 * frac);
-  cairo_stroke(cr);
-  cairo_arc(cr, 30, 40, 20, 224 * frac, 316 * frac);
-  cairo_stroke(cr);
-  cairo_arc(cr, 30, 40, 30, 224 * frac, 316 * frac);
-  cairo_stroke(cr);
-
-  pangoLayout = pango_cairo_create_layout(cr);
-  pango_layout_set_text(pangoLayout, CONNECT_NOW_HOME_PLUGIN(widget)->connection_name, -1);
-  const char* font = "Sans 10";
-  fontDescription = pango_font_description_from_string(font);
-  pango_layout_set_font_description(pangoLayout, fontDescription);
-  pango_font_description_free(fontDescription);
-  int width = 0;
-  int height = 0;
-  pango_layout_get_pixel_size(pangoLayout, &width, &height);
-
-  cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 1.0);
-  cairo_rectangle(cr, 0, CONNECT_NOW_WIDGET_WIDTH-height, CONNECT_NOW_WIDGET_WIDTH, height);
-  cairo_fill(cr);
-  cairo_save(cr);
-  if(width>CONNECT_NOW_WIDGET_WIDTH)
-  {
-    double factor = (double)CONNECT_NOW_WIDGET_WIDTH/width;
-    cairo_scale(cr, factor, factor);
-    cairo_move_to(cr, 0, (CONNECT_NOW_WIDGET_WIDTH/factor)-height);
+    GdkPixbuf* image = NULL;
+    if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_CONNECTED)
+    {
+      image = CONNECT_NOW_HOME_PLUGIN(widget)->connectedImage;
+    }
+    else
+    {
+      image = CONNECT_NOW_HOME_PLUGIN(widget)->disconnectedImage;
+    }
+    gdk_cairo_set_source_pixbuf(cr, image, 0.0, 0.0);
+    cairo_paint(cr);
   }
   else
   {
-    cairo_move_to(cr, (CONNECT_NOW_WIDGET_WIDTH - width)/2.0, CONNECT_NOW_WIDGET_WIDTH-height);
-  }
+    cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.0);
+    cairo_paint(cr);
 
-  cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
+    cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 0.4);
+    cairo_rectangle(cr, 0, 0, CONNECT_NOW_WIDGET_WIDTH, CONNECT_NOW_WIDGET_WIDTH);
+    cairo_fill(cr);
+
+    cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
+    cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
+    cairo_arc(cr, 42, 65, 3.0, 0, 2*M_PI);
+    cairo_fill(cr);
+
+    if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_CONNECTED)
+    {
+      cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
+    }
+    else if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_DISCONNECTED)
+    {
+      cairo_set_source_rgba(cr, 0.6, 0.6, 0.6, 0.7);
+    }
+    else if(CONNECT_NOW_HOME_PLUGIN(widget)->this_connection_state == CON_IC_STATUS_DISCONNECTING)
+    {
+      cairo_set_source_rgba(cr, 0.8, 0.8, 0.8, 1.0);
+    }
     
-  pango_cairo_show_layout(cr, pangoLayout);
-  cairo_restore(cr);  
-  cairo_pattern_t* linepattern = cairo_pattern_create_linear(0.0, 0.0, 0.0, CONNECT_NOW_WIDGET_WIDTH - height);
-  cairo_pattern_add_color_stop_rgba(linepattern, 0.0, 1.0, 1.0, 1.0, 0.0);
-  cairo_pattern_add_color_stop_rgba(linepattern, 0.5, 1.0, 1.0, 1.0, 0.35);
-  cairo_pattern_add_color_stop_rgba(linepattern, 1.0, 1.0, 1.0, 1.0, 0.0);
-  cairo_set_source(cr, linepattern);
-  cairo_rectangle(cr, 0, 0, CONNECT_NOW_WIDGET_WIDTH, CONNECT_NOW_WIDGET_WIDTH-height);
-  cairo_fill(cr);
-  cairo_pattern_destroy(linepattern);
+    cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND); 
+
+    cairo_set_line_width(cr, 6.0);
+    double frac = (M_PI/180.0);
+    cairo_arc(cr, 42, 63, 10, 224 * frac, 316 * frac);
+    cairo_stroke(cr);
+    cairo_arc(cr, 42, 63, 25, 224 * frac, 316 * frac);
+    cairo_stroke(cr);
+    cairo_arc(cr, 42, 63, 40, 224 * frac, 316 * frac);
+    cairo_stroke(cr);
+    cairo_arc(cr, 42, 63, 55, 224 * frac, 316 * frac);
+    cairo_stroke(cr);
+
+    pangoLayout = pango_cairo_create_layout(cr);
+    pango_layout_set_text(pangoLayout, CONNECT_NOW_HOME_PLUGIN(widget)->connection_name, -1);
+    const char* font = "Sans 12";
+    fontDescription = pango_font_description_from_string(font);
+    pango_layout_set_font_description(pangoLayout, fontDescription);
+    pango_font_description_free(fontDescription);
+    int width = 0;
+    int height = 0;
+    pango_layout_get_pixel_size(pangoLayout, &width, &height);
+
+    cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 1.0);
+    cairo_rectangle(cr, 0, CONNECT_NOW_WIDGET_WIDTH-height, CONNECT_NOW_WIDGET_WIDTH, height);
+    cairo_fill(cr);
+    cairo_save(cr);
+    if(width>CONNECT_NOW_WIDGET_WIDTH)
+    {
+      double factor = (double)CONNECT_NOW_WIDGET_WIDTH/width;
+      cairo_scale(cr, factor, factor);
+      cairo_move_to(cr, 0, (CONNECT_NOW_WIDGET_WIDTH/factor)-height);
+    }
+    else
+    {
+      cairo_move_to(cr, (CONNECT_NOW_WIDGET_WIDTH - width)/2.0, CONNECT_NOW_WIDGET_WIDTH-height);
+    }
+
+    cairo_set_source_rgba(cr, 1.0, 1.0, 1.0, 1.0);
+    
+    pango_cairo_show_layout(cr, pangoLayout);
+    cairo_restore(cr);  
+    cairo_pattern_t* linepattern = cairo_pattern_create_linear(0.0, 0.0, 0.0, CONNECT_NOW_WIDGET_WIDTH - height);
+    cairo_pattern_add_color_stop_rgba(linepattern, 0.0, 1.0, 1.0, 1.0, 0.0);
+    cairo_pattern_add_color_stop_rgba(linepattern, 0.5, 1.0, 1.0, 1.0, 0.35);
+    cairo_pattern_add_color_stop_rgba(linepattern, 1.0, 1.0, 1.0, 1.0, 0.0);
+    cairo_set_source(cr, linepattern);
+    cairo_rectangle(cr, 0, 0, CONNECT_NOW_WIDGET_WIDTH, CONNECT_NOW_WIDGET_WIDTH-height);
+    cairo_fill(cr);
+    cairo_pattern_destroy(linepattern);
+
+  }  
   cairo_destroy(cr);
-  
   return GTK_WIDGET_CLASS(connect_now_home_plugin_parent_class)->expose_event(widget, event);
 }
 
@@ -429,7 +468,11 @@ connect_now_plugin_finalize(GObject *object)
   g_free(desktop_plugin->connection_id);
   g_free(desktop_plugin->current_connection_id);
   g_free(desktop_plugin->connection_name);
+  g_free(desktop_plugin->connectedImageName);
+  g_free(desktop_plugin->disconnectedImageName);
   g_free(desktop_plugin->iD);
+  g_object_unref(desktop_plugin->connectedImage);
+  g_object_unref(desktop_plugin->disconnectedImage);
   G_OBJECT_CLASS (connect_now_home_plugin_parent_class)->finalize (object);
 }
 
